// Generated by CoffeeScript 1.12.4
(function() {
  var Express, OctobluRaven, bodyParser, compression, cors, enableDestroy, express, expressVersion, favicon, meshbluHealthcheck, morgan, path,
    bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };

  path = require('path');

  cors = require('cors');

  morgan = require('morgan');

  express = require('express');

  bodyParser = require('body-parser');

  compression = require('compression');

  OctobluRaven = require('octoblu-raven');

  enableDestroy = require('server-destroy');

  favicon = require('serve-favicon');

  meshbluHealthcheck = require('express-meshblu-healthcheck');

  expressVersion = require('express-package-version');

  Express = (function() {
    function Express(options) {
      this._middlewares = bind(this._middlewares, this);
      this._skip = bind(this._skip, this);
      this._raven = bind(this._raven, this);
      this._setOptions = bind(this._setOptions, this);
      var app;
      this._setOptions(options);
      app = express();
      enableDestroy(app);
      this._raven({
        app: app
      });
      this._middlewares({
        app: app
      });
      return app;
    }

    Express.prototype._setOptions = function(options) {
      if (options == null) {
        options = {};
      }
      this.disableLogging = options.disableLogging, this.disableCors = options.disableCors, this.logSuccesses = options.logSuccesses, this.faviconPath = options.faviconPath, this.bodyLimit = options.bodyLimit, this.logFn = options.logFn, this.logFormat = options.logFormat;
      if (this.disableLogging == null) {
        this.disableLogging = process.env.DISABLE_LOGGING === "true";
      }
      if (this.logSuccesses == null) {
        this.logSuccesses = process.env.LOG_SUCCESSES === "true";
      }
      if (this.slowLoggingMin == null) {
        this.slowLoggingMin = parseInt(process.env.SLOW_LOGGING_MIN || 1000);
      }
      if (process.env.NODE_ENV === 'production') {
        if (this.logFormat == null) {
          this.logFormat = 'short';
        }
      }
      if (this.logFormat == null) {
        this.logFormat = 'dev';
      }
      if (this.faviconPath == null) {
        this.faviconPath = path.join(__dirname, '..', 'assets', 'favicon.ico');
      }
      return this.bodyLimit != null ? this.bodyLimit : this.bodyLimit = '1mb';
    };

    Express.prototype._raven = function(arg) {
      var app, octobluRaven;
      app = arg.app;
      octobluRaven = new OctobluRaven({
        logFn: this.logFn
      });
      return octobluRaven.handleExpress({
        app: app
      });
    };

    Express.prototype._skip = function(request, response) {
      var responseTime, shouldLog, shouldNotLog;
      shouldLog = false;
      shouldNotLog = true;
      if (this.disableLogging) {
        return shouldNotLog;
      }
      if (this.logSuccesses) {
        return shouldLog;
      }
      responseTime = typeof morgan['response-time'] === "function" ? morgan['response-time'](request, response) : void 0;
      if (responseTime > this.slowLoggingMin) {
        return shouldLog;
      }
      if (response.statusCode > 300) {
        return shouldLog;
      }
      return shouldNotLog;
    };

    Express.prototype._middlewares = function(arg) {
      var app;
      app = arg.app;
      app.use(compression());
      app.use(meshbluHealthcheck());
      app.use(expressVersion({
        format: '{"version": "%s"}'
      }));
      app.use(morgan(this.logFormat, {
        immediate: false,
        skip: this._skip
      }));
      app.use(favicon(this.faviconPath));
      app.use(bodyParser.urlencoded({
        limit: this.bodyLimit,
        extended: true
      }));
      app.use(bodyParser.json({
        limit: this.bodyLimit
      }));
      if (!this.disableCors) {
        app.use(cors());
      }
      if (!this.disableCors) {
        return app.options('*', cors());
      }
    };

    return Express;

  })();

  module.exports = Express;

}).call(this);

//# sourceMappingURL=express.js.map
